//*******************************************************************************
// This do file is written by Minghao Li (minghao@iastate.edu) to combine US tariff increases
// and retaliatory tariffs from other countries with trade data, and to aggregate these tariff
// increases to GTAP commodities




// Change working directory to trade_war_tariffs

cd "C:\Research\trade_war\trade_war_tariffs"

//***********************************Concordance***********************************************************************

// The HS-code-to-gtap concordance is from: https://wits.worldbank.org/product_concordance.html 
import excel raw\hs_gtap.xlsx, sheet("JobID-58_Concordance_HS_to_GP") firstrow clear
drop if hs6==121299&GTAP_Code==8 //drop the one in OCR
drop if hs6==140390&GTAP_Code==8 
drop if hs6==590699&GTAP_Code==33 
rename hs6 hs6_2007
save intermediate\hs_gtap.dta,replace


//The following codes creat a crosswalk between hs4 and 
//GTAP commodities for those hs4 commodities that can be matched to a unique gtap commodity
gen hs4=trunc(hs6_2007/100)
gen hsGTAP= hs4*100+ GTAP_Code
collapse hs4 GTAP_Code (first) GTAP_commodity, by ( hsGTAP ) 
duplicates tag hs4, gen(dup)
keep if dup==0
save intermediate\hs_gtap1.dta,replace

//This loads  mannually entered crosswalks for hs4 commodities that cannot be matched to a unique GTAP commodity according to the WITS concordance
import excel raw\hs_gtap_manual.xlsx, sheet("Sheet2") firstrow clear //fixed two wrong links in the source for pork livers
save intermediate\hs_gtap2.dta,replace

import excel raw\hs_gtap_manual2.xlsx, sheet("Sheet1") firstrow clear //fixed two wrong links in the source for pork livers
save intermediate\hs_gtap3.dta,replace


//This a crosswalk between HS2017 to HS2007 
import excel raw\HS2017toHS2007.xlsx, sheet("Conversion HS17-HS07") firstrow clear
destring,force replace
save intermediate\hs17to07.dta,replace

//This is a file with the importing and exporting countries, and the dates, of each tariff increases
import excel raw\tariffindex.xlsx, sheet("Sheet1") firstrow clear
save intermediate\tariff_index.dta, replace


//***********************************trade data***********************************************************************

forvalues i=1(1)6 {
import excel raw\trade\EU_import_export`i'.xlsx, sheet("1") firstrow clear
save intermediate\eu`i'.dta,replace
}

forvalues i=1(1)3 {
import excel using raw\trade\steel_countries_import`i'.xlsx, sheet("1") firstrow clear
gen TradeFlow="Import"
save intermediate\steel`i'.dta,replace
}

forvalues i=1(1)5 {
append using intermediate\eu`i'.dta
}
keep TradeFlow Partner hs6 value
collapse value,by ( TradeFlow hs6 )
gen Partner="EU"
save intermediate\eu_long.dta,replace


import excel raw\trade\IND_TRK_Export.xlsx, sheet("1") firstrow clear
save intermediate\IND_TRK.dta,replace
 
import excel raw\trade\import_export2016_CN_CA_MX.xlsx, sheet("Comtrade") firstrow clear
keep TradeFlow Partner hs6 value
drop if TradeFlow=="Re-Export"
append using intermediate\eu_long.dta

forvalues i=1(1)3 {
append using intermediate\steel`i'.dta
}
append using intermediate\IND_TRK.dta

gen cty_flow= Partner+ TradeFlow
drop TradeFlow Partner description
rename value v
replace v=v/1000000   //Million dollars
reshape wide v, i(hs6) j(cty_flow) string

save intermediate\trade_data.dta,replace

//****************************Tariff data************************************

//Import tariff data

forvalues sheet=1(1)15 {
import excel tariff_list.xlsx, sheet(`sheet') firstrow clear
destring hscode hslevel,force replace
rename hscode hs8
gen hs6=trunc(hs8/100)
drop if missing(hs8)
save intermediate/`sheet',replace
}

//US steel and aluminum tariffs are applied at 4, 6, and 8 hs levels. Store tariff data separately

import excel tariff_list.xlsx, sheet(16) firstrow clear
destring *increase,force replace
save intermediate/16,replace

keep if ~missing(hs8)
destring hs8,force replace
save intermediate/168,replace

use intermediate/16.dta
keep if ~missing(hs6)
keep hs6 *increase
save intermediate/166,replace

use intermediate/16.dta
keep if ~missing(hs4)
keep hs4 *increase
save intermediate/164,replace


use intermediate/1.dta

forvalues sheet=2(1)15 {
merge 1:1 hs8  using intermediate/`sheet'.dta,nogen
drop if missing(hs8)
}
drop if missing(hs8)
merge 1:1 hs8  using intermediate/168.dta,force nogen
merge m:1 hs6  using intermediate/trade_data.dta,force nogen
merge m:1 hs6  using intermediate/166.dta,force nogen
replace hs6=trunc(hs8/100) if missing(hs6)
replace hs4=trunc(hs6/100) if missing(hs4)
merge m:1 hs4  using intermediate/164.dta,force update nogen

//Mannually enter Indian and Turkish tariffs
//India tariff
gen india_tariff_increase=.
replace india_tariff_increase=0.05 if hs6==71310|hs6==71320|hs6==90111|hs6==100199|hs6==150710
replace india_tariff_increase=0.1 if  hs6==80131|hs6==80211|hs6==90111|hs6==151190|hs6==180100|hs6==180400|hs6==180500|hs6==180690
replace india_tariff_increase=0.2 if  hs6==80212
replace india_tariff_increase=0.3 if  hs6==80810
replace india_tariff_increase=0.5 if hs6==870310|hs6==870431|hs6==871150
replace india_tariff_increase=1 if hs6==80231|hs6==80232

//Turkey tariff
gen turkey_tariff_increase=.
replace turkey_tariff_increase=0.05 if hs4==802|hs6==271311|hs6==902219
replace turkey_tariff_increase=0.1 if (hs4==2701|hs4==4802|hs4==4804|hs6==210690|hs6==270400|hs6==390810|hs6==841370|hs6==847989)
replace turkey_tariff_increase=0.15 if hs4==4401
replace turkey_tariff_increase=0.2 if hs4==1006
replace turkey_tariff_increase=0.25 if hs4==2401|hs4==4811
replace turkey_tariff_increase=0.3 if hs4==3304|hs4==3926|hs6==550210|hs6==730890
replace turkey_tariff_increase=0.32 if hs6==390410
replace turkey_tariff_increase=0.35 if hs4==0.35
replace turkey_tariff_increase=0.4 if hs4==0.4


//This step fill the tariff increase of a hs6 code with the average of hs8 codes belonging to that hs6 code.
//Therefore if a hs6 code has multiple hs8 lines that experience tariff increase,
//The tariff increase for the hs6 code will be the simple average of the hs6 codes.
//For example if hs6 100001 has 10000101 (tariff increase 20% for a certain tariff increase), 10000102 (10%), and 10000103 (0%), 
//Then the hs6 tariff will be 15%. 10000103 will be ignored since it has missing data and will be ignored by collapse.
collapse *increase v*, by(hs6)
save intermediate/h6_tariff_trade.dta,replace


//If missing tariff increase or trade volumn, fill with zeros
mvencode *increase v*,mv(0)
export excel hs6 *increase using h6_tariff.xls, firstrow(variables) replace

//Cross walk the hs6 2017 code to 2007 to prepare for merging GTAP commodity categories
merge 1:m hs6 using intermediate/hs17to07.dta,
drop if _merge==2
drop _merge

//Merge the hs combined to gtap cross walk from WITS
merge m:1 hs6_2007 using intermediate/hs_gtap.dta
drop if _merge==2
drop _merge

gen hs4=trunc(hs6/100)
replace hs4=trunc(hs6_2007/100) if missing(hs4)

//If not matched, use hs4 to gtap crosswalk if the hs4 can be matched to a unique gtap commodity
merge m:1 hs4 using intermediate\hs_gtap1.dta, update nogen

//Is still not match, use the mannually created hs4 to gtap crosswalk
merge m:1 hs4 using intermediate\hs_gtap2.dta, update nogen

//Check the ones still not matched, there should only be one item "unclassified commodities, hs6=9999999"
summarize if missing( GTAP_commodity )
drop if missing(hs6)
drop if missing(GTAP_commodity)

//These codes are for breaking out pork, ethanol, and corn for another project. Most users can ignore this.
/*
gen GTAP_Code2=GTAP_Code
gen GTAP_commodity2=GTAP_commodity

//Corn, pork, and ethanol breakout
replace GTAP_Code2=45 if hs6==100510|hs6==100590
replace GTAP_commodity2="MAZ" if hs6==100510|hs6==100590

replace GTAP_Code2=46 if hs6==220710|hs6==220720
replace GTAP_commodity2="ETH" if hs6==220720|hs6==220720

gen pork=1 if (hs6==20311|hs6==20312|hs6==20319|hs6==20321|hs6==20322 ///
|hs6==20329|hs6==20641|hs6==20649|hs6==21011|hs6==21012|hs6==21019 ///
|hs6==50400|hs6==160241|hs6==160242|hs6==160249)

replace GTAP_Code2=47 if pork==1
replace GTAP_commodity2="PRK" if pork==1

drop pork
//encode GTAP_commodity2,gen(gtap_break)
*/


gen temp=subinstr(GTAP_commodity," ","",.)
encode temp,gen(gtap)
drop GTAP* dup hsGTAP hs4 hs6_2007 

//*****************use weighted sum to aggregate tariff increase to GTAP level*************************
//Generate rest of world import. Rest of the world includes all countreis other than China, Mexico, 
//Canada, EU, Turkey, India, and top 20 steel and aluminum exporters to the US.
gen vROWImport=vWorldImport- vChinaImport- vEUImport- vMexicoImport- vCanadaImport
local steel "ARE ARG AUS BHR IND JPN KOR QAT RUS THA TUR TWN VEN VNM ZAF BRA"
foreach cty of local steel {
replace vROWImport=vROWImport-v`cty'Import
}
replace vROWImport=0 if vROWImport<0


//Give a small trade volumn to zero trade volumn. This way items with zero trade volumn can be conserved.
replace vChinaExport=0.0000000001 if vChinaExport==0
replace vEUExport=0.0000000001 if vEUExport==0
replace vMexicoExport=0.0000000001  if vMexicoExport ==0
replace vCanadaExport=0.0000000001 if vCanadaExport==0
replace vChinaExport=0.0000000001 if vChinaExport==0
replace vIndiaExport=0.0000000001 if vCanadaExport==0
replace vTurkeyExport=0.0000000001 if vTurkeyExport==0
replace vChinaImport=0.00000000001 if vChinaImport==0
replace vEUImport=0.00000000001 if vEUImport==0
replace vMexicoImport=0.00000000001 if vMexicoImport==0
replace vCanadaImport=0.00000000001 if vCanadaImport==0


//Multiplied by weights
gen us_cn_sa_tariff_increase=us_sa_tariff_increase
gen us_eu_sa_tariff_increase=us_sa_tariff_increase
gen us_mx_sa_tariff_increase=us_sa_tariff_increase
gen us_ca_sa_tariff_increase=us_sa_tariff_increase


local steel "ARE ARG AUS BHR IND JPN KOR QAT RUS THA TUR TWN VEN VNM ZAF BRA ROW"
foreach cty of local steel {
replace v`cty'Import=0.00000001 if v`cty'Import==0
asgen tariff_increase_us_`cty'_sa= us_sa_tariff_increase ,weights( v`cty'Import ) by (gtap)
}

drop us_sa_tariff_increase


//Adjust for steel exemptions
replace tariff_increase_us_KOR_sa=0 if hs6<760000
replace tariff_increase_us_ARG_sa=0 if hs6<760000
replace tariff_increase_us_AUS_sa=0 if hs6<760000
replace tariff_increase_us_BRA_sa=0 if hs6<760000

//Adjust for aluminum excemptions
replace tariff_increase_us_ARG_sa=0 if hs6>=760000
replace tariff_increase_us_AUS_sa=0 if hs6>=760000

//Sum weight*tariff increase, and sum weight

asgen tariff_increase_chn3= chn3_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn34 = chn34_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn16= chn16_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn60b1= chn60b1_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn60b2 = chn60b2_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn75b1 = chn75b1_tariff_increase ,weights( vChinaExport ) by (gtap)
asgen tariff_increase_chn75b2 = chn75b2_tariff_increase ,weights( vChinaExport ) by (gtap)


asgen tariff_increase_EU1 = EU1_tariff_increase ,weights( vEUExport ) by (gtap)
asgen tariff_increase_EU2 = EU2_tariff_increase ,weights( vEUExport  ) by (gtap)
asgen tariff_increase_mexb = mexb_tariff_increase ,weights( vMexicoExport) by (gtap)
asgen tariff_increase_can = can_tariff_increase ,weights( vCanadaExport  ) by (gtap)
asgen tariff_increase_india = india_tariff_increase ,weights( vIndiaExport ) by (gtap)
asgen tariff_increase_turkey = turkey_tariff_increase ,weights( vTurkeyExport ) by (gtap)



asgen tariff_increase_uscn34 = uscn34_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_uscn16 = uscn16_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us200b1 = us200b1_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us200b2 = us200b2_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us300b1 = us300b1_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us300b2 = us300b2_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us_cn_sa = us_cn_sa_tariff_increase ,weights( vChinaImport ) by (gtap)
asgen tariff_increase_us_eu_sa = us_eu_sa_tariff_increase ,weights( vEUImport ) by (gtap)
asgen tariff_increase_us_mx_sa = us_mx_sa_tariff_increase ,weights( vMexicoImport ) by (gtap)
asgen tariff_increase_us_ca_sa = us_ca_sa_tariff_increase ,weights( vCanadaImport ) by (gtap)



collapse tariff_increase_* (rawsum) v*,by (gtap)



asgen weighted_chn3= tariff_increase_chn3 ,weights( vChinaExport ) 
asgen weighted_chn34 = tariff_increase_chn34 ,weights( vChinaExport ) 
asgen weighted_chn16= tariff_increase_chn16 ,weights( vChinaExport ) 
asgen weighted_chn60b1= tariff_increase_chn60b1 ,weights( vChinaExport ) 
asgen weighted_chn60b2 = tariff_increase_chn60b2 ,weights( vChinaExport ) 
asgen weighted_chn75b1 = tariff_increase_chn75b1 ,weights( vChinaExport ) 
asgen weighted_chn75b2 = tariff_increase_chn75b2 ,weights( vChinaExport ) 


asgen weighted_EU1 = tariff_increase_EU1 ,weights( vEUExport ) 
asgen weighted_EU2 = tariff_increase_EU2 ,weights( vEUExport  ) 
asgen weighted_mexb = tariff_increase_mexb ,weights( vMexicoExport) 
asgen weighted_can = tariff_increase_can ,weights( vCanadaExport  ) 
asgen weighted_india = tariff_increase_india ,weights( vIndiaExport ) 
asgen weighted_turkey = tariff_increase_turkey ,weights( vTurkeyExport ) 



asgen weighted_uscn34 = tariff_increase_uscn34 ,weights( vChinaImport ) 
asgen weighted_uscn16 = tariff_increase_uscn16 ,weights( vChinaImport ) 
asgen weighted_us200b1 = tariff_increase_us200b1 ,weights( vChinaImport ) 
asgen weighted_us200b2 = tariff_increase_us200b2 ,weights( vChinaImport ) 
asgen weighted_us300b1 = tariff_increase_us300b1 ,weights( vChinaImport ) 
asgen weighted_us300b2 = tariff_increase_us300b2 ,weights( vChinaImport ) 
asgen weighted_us_cn_sa = tariff_increase_us_cn_sa ,weights( vChinaImport ) 
asgen weighted_us_eu_sa = tariff_increase_us_eu_sa ,weights( vEUImport ) 
asgen weighted_us_mx_sa = tariff_increase_us_mx_sa ,weights( vMexicoImport ) 
asgen weighted_us_ca_sa = tariff_increase_us_ca_sa ,weights( vCanadaImport ) 


drop weighted* v*






reshape long tariff_increase_,i(gtap) j(tariff_name) string
merge m:1 tariff_name using intermediate/tariff_index.dta, nogen


replace tariff_increase_=0 if tariff_name=="us_ca_sa_"|tariff_name=="us_mx_sa_"|tariff_name=="can_"|tariff_name=="mexb_"



export excel using gtap_tariff_aggregate.xls, firstrow(varlabels) replace

